==> darequest-0.1.0.tar.gz: lib/request.dart <==
import 'dart:async';
import 'dart:convert';
import 'dart:io';

import 'interceptor/interceptor.dart';
import 'exceptions/response_exception.dart';
import 'request_option.dart';
import 'response.dart';

class Request {
  static Interceptor interceptor = new Interceptor();
  static bool responseFailThrow = true;
  static bool parseResponse = true;
  static Map<String, Object> defaultOptions = {
    "url": null,
    "method": RequestOption.METHOD_GET,
    "headers": {"Accept": "application/json", "Content-Type": ContentType.JSON.toString()},
    "params": {},
    "data": {},
    "meta": {},
  };

  static Future<Response> request(RequestOption option) {
    return getConfig(option).then((config) {
      HttpClient client = new HttpClient();
      String url = config.url;
      Uri parse = Uri.parse(url);
      config.params.addAll(parse.queryParameters);

      Uri target = new Uri(scheme: parse.scheme, host: parse.host, path: parse.path, queryParameters: config.params);

      return client.openUrl(config.method, target).then((client) {
        config.headers.forEach((k, v) {
          client.headers.set(k, v);
        });
        setRequestData(client, config);
        // ignore: return_of_invalid_type_from_closure
        return client.close().then((response) {
          return parseResponseBody(response).then((responseBody) {
            if (responseFailThrow && response.statusCode != 200) {
              throw new ResponseException(response: response, responseBody: responseBody);
            }
            Response resp = new Response(response: response, responseBody: responseBody);

            return interceptor.success(resp, config);
          });
        }).catchError((e) => interceptor.fail(e, config));
      });
    });
  }

  static void setRequestData(HttpClientRequest client, RequestOption config) {
    client.contentLength = -1;
    var contentType = config.headers['Content-Type'];
    if (contentType is String && contentType.contains('application/json')) {
      client.write(JSON.encode(config.data));
    } else {
      client.write(config.data);
    }
  }

  static Future<Response> get(String url, [Map<String, Object> options]) {
    RequestOption option = getOptionByMap(url, RequestOption.METHOD_GET, {}, options);

    return request(option);
  }

  static Future<Response> delete(String url, [Map<String, Object> options]) {
    RequestOption option = getOptionByMap(url, RequestOption.METHOD_DELETE, {}, options);

    return request(option);
  }

  static Future<Response> post(String url, [dynamic data, Map<String, Object> options]) {
    RequestOption option = getOptionByMap(url, RequestOption.METHOD_POST, data, options);

    return request(option);
  }

  static Future<Response> put(String url, [dynamic data, Map<String, Object> options]) {
    RequestOption option = getOptionByMap(url, RequestOption.METHOD_PUT, data, options);

    return request(option);
  }

  static Future<RequestOption> getConfig(option) {
    var config = interceptor.config(option);
    if (config is Future) {
      return config;
    }
    return new Future.value(config);
  }

  static RequestOption getOptionByMap(String url, String method, [dynamic data, Map<String, Object> options]) {
    if (options == null) {
      options = {};
    }
    options['data'] = data;

    defaultOptions.addAll(options);
    RequestOption option = new RequestOption(
        url: url, method: method, headers: defaultOptions['headers'], params: defaultOptions['params'], data: defaultOptions['data']);
    return option;
  }

  static Future<dynamic> parseResponseBody(HttpClientResponse response) {
    if (!parseResponse) {
      return new Future.value(null);
    }

    Future<String> body = response.transform(UTF8.decoder).join();

    return body.then((str) {
      String mimeType = response.headers.contentType.mimeType;
      var data = str;
      if (mimeType == 'application/json') {
        try {
          data = JSON.decode(str);
        } catch (e) {
        }
      }

      return data;
    });
  }
}

==> darequest-0.2.2.tar.gz: lib/request.dart <==
import 'dart:async';
import 'dart:convert';
import 'dart:io';

import 'package:http_parser/http_parser.dart' as httpParser;

import 'interceptor/interceptor.dart';
import 'exceptions/response_exception.dart';
import 'request_option.dart';
import 'response.dart';
import 'package:http/http.dart' as http;

export 'request_option.dart';
export 'response.dart';

class Request {
  static Interceptor interceptor = new Interceptor();
  static bool responseFailThrow = true;
  static bool parseResponse = true;
  static Map<String, Object> defaultOptions = {
    "url": null,
    "method": RequestOption.METHOD_GET,
    "headers": {"Accept": "application/json", "Content-Type": ContentType.JSON.toString()},
    "params": {},
    "data": {},
    "meta": {},
  };

  static Future<Response<HttpClientResponse>> request(RequestOption option) {
    return getConfig(option).then((config) {
      HttpClient client = new HttpClient();
      Uri target = getUriByConfig(config);

      return client.openUrl(config.method, target).then((client) {
        config.headers.forEach((k, v) {
          client.headers.set(k, v);
        });
        setRequestData(client, config);
        // ignore: return_of_invalid_type_from_closure
        return client.close().then((response) {
          return parseResponseBody(response).then((responseBody) {
            if (responseFailThrow && response.statusCode != 200) {
              throw new ResponseException(response: response, responseBody: responseBody);
            }
            Response resp = new Response(response: response, responseBody: responseBody);

            return interceptor.success(resp, config);
          });
        }).catchError((e) => interceptor.fail(e, config));
      });
    });
  }

  static Uri getUriByConfig(RequestOption config) {
    String url = config.url;
    Uri parse = Uri.parse(url);
    config.params.addAll(parse.queryParameters);

    Uri target = new Uri(scheme: parse.scheme, host: parse.host, path: parse.path, port: parse.port, queryParameters: config.params);
    return target;
  }

  static void setRequestData(HttpClientRequest client, RequestOption config) {
    client.contentLength = -1;
    var contentType = config.headers['Content-Type'];
    if (contentType is String && contentType.contains('application/json')) {
      client.write(JSON.encode(config.data));
    } else {
      client.write(config.data);
    }
  }

  static Future<Response> get(String url, [Map<String, Object> options]) {
    RequestOption option = getOptionByMap(url, RequestOption.METHOD_GET, {}, options);

    return request(option);
  }

  static Future<Response> delete(String url, [Map<String, Object> options]) {
    RequestOption option = getOptionByMap(url, RequestOption.METHOD_DELETE, {}, options);

    return request(option);
  }

  static Future<Response> post(String url, [dynamic data, Map<String, Object> options]) {
    RequestOption option = getOptionByMap(url, RequestOption.METHOD_POST, data, options);

    return request(option);
  }

  static Future<Response> put(String url, [dynamic data, Map<String, Object> options]) {
    RequestOption option = getOptionByMap(url, RequestOption.METHOD_PUT, data, options);

    return request(option);
  }

  static Future<Response<http.StreamedResponse>> upload(String url, String filePath,
      { String method = RequestOption.METHOD_POST,
        String name,
        String field = 'file',
        Map<String, String> fields = const {},
        Map<String, Object> options = const {},
        String type = 'application/octet-stream'}) {

    RequestOption option = getOptionByMap(url, method, fields, options);
    return getConfig(option).then((config) {
      Uri target = getUriByConfig(config);
      http.MultipartRequest request = new http.MultipartRequest(method, target);
      config.headers.forEach((key, value) {
        if (key != "Content-Type") {
          request.headers[key] = value;
        }
      });
      request.fields.addAll(fields);
      httpParser.MediaType contentType = new httpParser.MediaType.parse(type);
      return http.MultipartFile.fromPath(field, filePath, filename: name, contentType: contentType).then((file) {
        request.files.add(file);

        return request.send().then((response) async {
          var responseBody = null;
          var type = response.headers['content-type'];
          if (parseResponse && type is String && type.contains('application/json')) {
            responseBody = decodeJson(await response.stream.bytesToString());
          }

          if (responseFailThrow && response.statusCode != 200) {
            throw new ResponseException<http.StreamedResponse>(response: response, responseBody: responseBody);
          }
          Response<http.StreamedResponse> resp = new Response(response: response, responseBody: responseBody);

          return interceptor.success(resp, config);
        }).catchError((e) => interceptor.fail(e, config));
      });
    });
  }

  static Future<RequestOption> getConfig(option) {
    var config = interceptor.config(option);
    if (config is Future) {
      return config;
    }
    return new Future.value(config);
  }

  static RequestOption getOptionByMap(String url, String method, [dynamic data, Map<String, Object> options]) {
    if (options == null) {
      options = {};
    }
    defaultOptions['data'] = data;

    defaultOptions.addAll(options);
    RequestOption option = new RequestOption(
        url: url, method: method, headers: defaultOptions['headers'], params: defaultOptions['params'], data: defaultOptions['data']);
    return option;
  }

  static Future<dynamic> parseResponseBody(HttpClientResponse response) {
    if (!parseResponse) {
      return new Future.value(null);
    }

    Future<String> body = response.transform(UTF8.decoder).join();

    return body.then((str) {
      String mimeType = response.headers.contentType.mimeType;
      var data = str;
      if (mimeType == 'application/json') {
        data = decodeJson(str);
      }

      return data;
    });
  }

  static dynamic decodeJson(str){
    var data = str;
    try {
      data = JSON.decode(str);
    } catch (e) {}
    return data;
  }
}
